/* This file was generated by syncqt. */
#ifndef QT_QTSCRIPT_VERSION_H
#define QT_QTSCRIPT_VERSION_H

#define QTSCRIPT_VERSION_STR "5.12.8"

#define QTSCRIPT_VERSION 0x050C08

#endif // QT_QTSCRIPT_VERSION_H
